[llvm-commits] CVS: llvm-tv/lib/Snapshot/FileUtils.cpp ReadSnapshots.cpp WriteSnapshot.cpp

Misha Brukman brukman at cs.uiuc.edu
Tue Oct 5 11:38:36 PDT 2004



Changes in directory llvm-tv/lib/Snapshot:

FileUtils.cpp updated: 1.5 -> 1.6
ReadSnapshots.cpp updated: 1.2 -> 1.3
WriteSnapshot.cpp updated: 1.9 -> 1.10
---
Log message:

Adjust for #include file being moved and PassManager API change.


---
Diffs of the changes:  (+15 -14)

Index: llvm-tv/lib/Snapshot/FileUtils.cpp
diff -u llvm-tv/lib/Snapshot/FileUtils.cpp:1.5 llvm-tv/lib/Snapshot/FileUtils.cpp:1.6
--- llvm-tv/lib/Snapshot/FileUtils.cpp:1.5	Sat May 15 00:48:22 2004
+++ llvm-tv/lib/Snapshot/FileUtils.cpp	Tue Oct  5 13:38:25 2004
@@ -12,7 +12,7 @@
 //
 //===----------------------------------------------------------------------===//
 
-#include "Support/FileUtils.h"
+#include "llvm-tv/Support/FileUtils.h"
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <dirent.h>


Index: llvm-tv/lib/Snapshot/ReadSnapshots.cpp
diff -u llvm-tv/lib/Snapshot/ReadSnapshots.cpp:1.2 llvm-tv/lib/Snapshot/ReadSnapshots.cpp:1.3
--- llvm-tv/lib/Snapshot/ReadSnapshots.cpp:1.2	Tue Apr 13 13:36:21 2004
+++ llvm-tv/lib/Snapshot/ReadSnapshots.cpp	Tue Oct  5 13:38:25 2004
@@ -12,8 +12,8 @@
 
 #include "llvm/Module.h"
 #include "llvm/Bytecode/Reader.h"
-#include "Support/FileUtils.h"
-#include "Support/Snapshots.h"
+#include "llvm-tv/Support/FileUtils.h"
+#include "llvm-tv/Support/Snapshots.h"
 #include <string>
 #include <vector>
 using namespace llvm;


Index: llvm-tv/lib/Snapshot/WriteSnapshot.cpp
diff -u llvm-tv/lib/Snapshot/WriteSnapshot.cpp:1.9 llvm-tv/lib/Snapshot/WriteSnapshot.cpp:1.10
--- llvm-tv/lib/Snapshot/WriteSnapshot.cpp:1.9	Sat May 15 00:48:33 2004
+++ llvm-tv/lib/Snapshot/WriteSnapshot.cpp	Tue Oct  5 13:38:25 2004
@@ -16,12 +16,12 @@
 #include "llvm/Module.h"
 #include "llvm/Pass.h"
 #include "llvm/Bytecode/WriteBytecodePass.h"
+#include "llvm/ADT/StringExtras.h"
+#include "llvm/Support/CommandLine.h"
+#include "llvm/Support/Debug.h"
+#include "llvm/Support/SystemUtils.h"
+#include "llvm-tv/Support/FileUtils.h"
 #include "llvm-tv/Config.h"
-#include "Support/CommandLine.h"
-#include "Support/Debug.h"
-#include "Support/FileUtils.h"
-#include "Support/StringExtras.h"
-#include "Support/SystemUtils.h"
 #include <csignal>
 #include <cstdlib>
 #ifndef _GNU_SOURCE
@@ -46,8 +46,9 @@
       AU.setPreservesAll();
     }
     
-    /// run - save the Module in a pre-defined location with our naming strategy
-    bool run(Module &M);
+    /// runPass - save the Module in a pre-defined location with our naming
+    /// strategy
+    bool runPass(Module &M);
 
   private:
     bool sendSignalToLLVMTV();
@@ -63,11 +64,11 @@
 }
 
 
 /// run - save snapshot to a pre-defined directory with a consecutive number in
 /// the name (for alphabetization) and the name of the pass that ran just before
 /// this one. Signal llvm-tv that fresh bytecode file has arrived for
 /// consumption.
-bool Snapshot::run(Module &M) {
+bool Snapshot::runPass(Module &M) {
   // Make sure the snapshots dir exists, which it will unless this
   // is the first time we've ever run the -snapshot pass.
   EnsureDirectoryExists (llvmtvPath);
@@ -63,11 +64,11 @@
 
 
-/// run - save snapshot to a pre-defined directory with a consecutive number in
-/// the name (for alphabetization) and the name of the pass that ran just before
-/// this one. Signal llvm-tv that fresh bytecode file has arrived for
+/// runPass - save snapshot to a pre-defined directory with a consecutive number
+/// in the name (for alphabetization) and the name of the pass that ran just
+/// before this one. Signal llvm-tv that fresh bytecode file has arrived for
 /// consumption.






More information about the llvm-commits mailing list